@@ -134,6 +134,7 @@ ggseqdplot <- function(seqdata,
 
   if (is.null(attributes(seqdata)$weights)) weighted <- FALSE
 
+
   if (is.null(group)) group <- 1
 
   if (!is.null(facet_ncol) && as.integer(facet_ncol) != facet_ncol) {
@@ -144,6 +145,12 @@ ggseqdplot <- function(seqdata,
     stop("`facet_nrow` must be NULL or an integer.")
   }
 
+  if ("haven_labelled" %in% class(group)) {
+    group_name <- deparse(substitute(group))
+    group <- haven::as_factor(group)
+    cli::cli_warn(c("i" = "group vector {.arg {group_name}} is of class {.cls haven_labelled} and has been converted into a factor"))
+  }
+
   if (is.factor(group)) {
     group <- forcats::fct_drop(group)
     grinorder <- levels(group)
@@ -269,14 +276,16 @@ ggseqdplot <- function(seqdata,
       ggplot(aes(fill = .data$state, y = .data$value, x = .data$x)) +
       geom_bar(
         stat = "identity",
-        width = 1
+        width = 1,
+        show.legend = T
       )
   } else {
     ggdplot <- dplotdata |>
       ggplot(aes(fill = .data$state, y = .data$value, x = .data$x)) +
       geom_bar(
         stat = "identity",
-        width = 1, color = "black"
+        width = 1, color = "black",
+        show.legend = T
       )
   }
 
